@@ -41,6 +41,9 @@ class Client:
             iClient(**kwargs)
         ]
 
+        self.iClient_subscriptions = None
+
+
     # Mock Switcher
     def __which(self, topic: str) -> object:
         if self.__keyword in topic: return self.clients[1]
@@ -70,12 +73,39 @@ class Client:
         if isinstance(topic, list):
             c0_topics, c1_topics = self.__map_clients_to_topic(topic= list(topic))
             self.clients[0].subscribe(topic=c0_topics, callback=callback)
-            self.clients[1].subscribe(topic=c1_topics, callback=callback)
+            self.iClient_subscriptions = self.clients[1].subscribe(topic=c1_topics, callback=callback)
             return
 
         client = self.__which(topic=topic)
+        if(isinstance(client, iClient)):
+            self.iClient_subscriptions = client.subscribe(topic=topic, callback=callback, **kwargs)
         client.subscribe(topic=topic, callback=callback, **kwargs)
 
+    def __kill_all_threads(self):
+        thread_list = [sub.thread for sub in self.iClient_subscriptions]
+        for thread in thread_list:
+            #print(f"Closing thread: {thread}")
+            thread.terminate()
+            #print(f"Terminating thread: {thread}")
+            thread.join()
+            #print(f"Closed thread: {thread}")
+
+    def stop(self):
+        self.__kill_all_threads()
+
     def publish(self, topic: str, payload: str, **kwargs):
         client = self.__which(topic=topic)
         client.publish(topic=topic, payload=payload, **kwargs)
+
+    def loop(self, **kwargs):
+        self.clients[0].client.loop(**kwargs)
+
+    def loop_start(self):
+        self.clients[0].client.loop_start()
+
+    def loop_stop(self, **kwargs):
+        self.clients[0].client.loop_stop(**kwargs)
+        self.__kill_all_threads()
+
+    def loop_forever(self, **kwargs):
+        self.clients[0].client.loop_forever(**kwargs)
